package org.eclipse.soda.dk.gps.nmea.adapter;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import org.eclipse.soda.dk.adapter.DeviceAdapter;
import org.eclipse.soda.dk.adapter.service.AdapterService;
import org.eclipse.soda.dk.device.service.DeviceService;
import org.eclipse.soda.dk.gps.nmea.adapter.service.GpsNmeaAdapterService;
import org.eclipse.soda.dk.interest.InterestMask;
import org.eclipse.soda.dk.interest.service.InterestService;

/**
 * Global Positioning System (GPS) National Marine Electronics Association (NMEA) Adapter.
 * The GpsNmeaAdapter class implements the GpsNmeaAdapterService and provides the controls for the adapter.
 * <p>The list of exported services:
 * @see org.eclipse.soda.dk.gps.nmea.adapter.service.GpsNmeaAdapterService
 * @see org.eclipse.soda.dk.adapter.service.AdapterService
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class GpsNmeaAdapter extends DeviceAdapter implements AdapterService, GpsNmeaAdapterService {
	/**
	 * Defines the full class name.
	 * @since 1.0
	 */
	/* Generated field and should not be changed. */
	public static final String CLASS_NAME = "org.eclipse.soda.dk.gps.nmea.adapter.GpsNmeaAdapter"; //$NON-NLS-1$

	/**
	 * The interest filter for the device.
	 * @since 1.0
	 */
	/* Generated field and should not be changed. */
	private final InterestService interest = new InterestMask(new byte[] { 0x24, 0x47, 0x50, 0x42, 0x44, 0x40 }, new byte[] { -1, -1, -1, (byte) 0xe2, (byte) 0xe4, (byte) 0xf0 });

	/**
	 * Custom parameter rate.
	 * @since 1.0
	 */
	/* Generated field and should not be changed. */
	private int rate = 0;

	/**
	 * Constructs a new instance of the GpsNmeaAdapter class.
	 * @since 1.0
	 */
	public GpsNmeaAdapter() {
		super();
		setKey(getDefaultKey());
		initialize();
	}

	/**
	 * Gets the default device (DeviceService) value.
	 * @return DeviceService The default DeviceService.
	 * @since 1.2
	 */
	public DeviceService getDefaultDevice() {
		/* Generated method and should not be changed. */
		return (DeviceService) loadService(DeviceService.SERVICE_NAME, "org.eclipse.soda.dk.gps.nmea.device.GpsNmeaDevice"); //$NON-NLS-1$
	}

	/**
	 * Gets the default key (String) value.
	 * @return String The default key
	 * @since 1.2
	 */
	public String getDefaultKey() {
		return GpsNmeaAdapterService.GpsNmeaAdapter;
	}

	/**
	 * Gets the interest (InterestService) value.
	 * @return InterestService The interest filter for this adapter.
	 * @since 1.2
	 */
	public InterestService getInterest() {
		return this.interest;
	}

	/**
	 * Gets the value of rate custom parameter.
	 * @return rate custom parameter.
	 * @see #setRate(int)
	 * @since 1.2
	 */
	public int getRate() {
		return this.rate;
	}

	/**
	 * Create and initialize the controls for this adapter.
	 * @since 1.0
	 */
	private void initialize() {
		/* do nothing */
	}

	/**
	 * Is device needed.
	 * @return The results of this method.
	 * @since 1.2
	 */
	public boolean isDeviceNeeded() {
		return true;
	}

	/**
	 * Sets the value of rate custom parameter.
	 * @param rate The rate custom parameter.
	 * @see #getRate()
	 * @since 1.2
	 */
	public void setRate(final int rate) {
		this.rate = rate;
	}

	/**
	 * @see org.eclipse.soda.dk.device.Container#setup()
	 * @since 1.0
	 */
	public void setup() {
		/* Generated method and should not be changed. */
		super.setup();
		setNotificationPriority(getInt("gpsnmeaadapter.notificationpriority", getNotificationPriority()));setRate(getInt("gpsnmeaadapter.rate", getRate())); //$NON-NLS-1$ //$NON-NLS-2$
	}
}
