package org.eclipse.soda.dk.gps.nmea.adapter.factory;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.util.Dictionary;
import java.util.Hashtable;
import org.eclipse.soda.dk.adapter.factory.AdapterFactory;
import org.eclipse.soda.dk.adapter.service.AdapterService;
import org.eclipse.soda.dk.device.service.DeviceService;
import org.eclipse.soda.dk.gps.nmea.adapter.GpsNmeaAdapter;
import org.eclipse.soda.dk.gps.nmea.adapter.service.GpsNmeaAdapterService;
import org.eclipse.soda.dk.gps.nmea.device.service.GpsNmeaDeviceService;
import org.eclipse.soda.dk.notification.service.NotificationService;
import org.eclipse.soda.sat.core.framework.interfaces.IBundleActivationManager;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.Constants;

/**
 * Global Positioning System (GPS) National Marine Electronics Association (NMEA) Adapter.
 * <p>The device bundle activator class creates and registers the GpsNmeaAdapter device.
 * <p>The list of exported services:
 * @see org.eclipse.soda.dk.gps.nmea.adapter.service.GpsNmeaAdapterService
 * @see org.eclipse.soda.dk.adapter.service.AdapterService
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class GpsNmeaAdapterFactory extends AdapterFactory implements BundleActivator {
	/**
	 * Defines the full class name.
	 * @since 1.0
	 */
	/* Generated field and should not be changed. */
	public static final String CLASS_NAME = "org.eclipse.soda.dk.gps.nmea.adapter.factory.GpsNmeaAdapterFactory"; //$NON-NLS-1$

	/**
	 * Defines the service name(s) to be registered by the GpsNmeaAdapter bundle.
	 * <table>
	 * <tr>
	 * <td>org.eclipse.soda.dk.adapter.service.AdapterService</td>
	 * </tr>
	 * <tr>
	 * <td>org.eclipse.soda.dk.gps.nmea.adapter.service.GpsNmeaAdapterService</td>
	 * </tr>
	 * </table>
	 * @since 1.0
	 */
	/* Generated field and should not be changed. */
	public static final String[] EXPORTED_SERVICE_NAMES = new String[] { AdapterService.SERVICE_NAME, GpsNmeaAdapterService.SERVICE_NAME };

	/**
	 * Defines the imported service name(s) to be registered by the GpsNmeaAdapter bundle.
	 * <table>
	 * <tr>
	 * <td>org.eclipse.soda.dk.gps.nmea.device.service.GpsNmeaDeviceService</td>
	 * </tr>
	 * <tr>
	 * <td>org.eclipse.soda.dk.notification.service.NotificationService</td>
	 * </tr>
	 * </table>
	 * @since 1.0
	 */
	/* Generated field and should not be changed. */
	public static final String[] IMPORTED_SERVICE_NAMES = new String[] { GpsNmeaDeviceService.SERVICE_NAME, NotificationService.SERVICE_NAME };

	/**
	 * Gets the properties to be registered with the service(s).
	 * @return Hashtable of properties.
	 * <table width=100%>
	 * <tr>
	 * <td width=50%>org.osgi.framework.Constants.SERVICE_PID</td>
	 * <td width=50%>GpsNmeaAdapterService.SERVICE_NAME</td>
	 * </tr>
	 * <tr>
	 * <td width=50%>org.osgi.framework.Constants.SERVICE_DESCRIPTION</td>
	 * <td width=50%>GpsNmeaAdapterService.SERVICE_DESCRIPTION</td>
	 * </tr>
	 * <tr>
	 * <td width=50%>org.osgi.framework.Constants.SERVICE_RANKING</td>
	 * <td width=50%>6</td>
	 * </tr>
	 * <tr>
	 * <td width=50%>org.osgi.framework.Constants.SERVICE_VENDOR</td>
	 * <td width=50%>IBM</td>
	 * </tr>
	 * </table>
	 * @since 1.2
	 */
	public Hashtable createProperties() {
		/* Generated method and should not be changed. */
		final Hashtable properties = super.createProperties();
		properties.put(Constants.SERVICE_PID, GpsNmeaAdapterService.SERVICE_NAME);
		properties.put(Constants.SERVICE_DESCRIPTION, GpsNmeaAdapterService.SERVICE_DESCRIPTION);
		properties.put(Constants.SERVICE_RANKING, "6"); //$NON-NLS-1$
		properties.put(Constants.SERVICE_VENDOR, "IBM"); //$NON-NLS-1$
		return properties;
	}

	/**
	 * Creates the adapter using the specified device service.
	 * @see org.eclipse.soda.dk.gps.nmea.adapter.GpsNmeaAdapter
	 * @param deviceService The device service to used when creating the adatper service.
	 * @return Object The adapter service created by this bundle.
	 * @since 1.2
	 */
	public AdapterService createService(final DeviceService deviceService) {
		final GpsNmeaAdapter adapter = new GpsNmeaAdapter();
		adapter.setDevice(deviceService);
		return adapter;
	}

	/**
	 * Return the exported service name(s) to be registered by the GpsNmeaAdapter bundle.
	 * @param pid PID.
	 * @param oldProperties old properties.
	 * @param properties properties.
	 * @param manager manager.
	 * @return String[] The exported service name(s).
	 * @since 1.2
	 */
	public String[] getExportedServiceNames(final String pid, final Dictionary oldProperties, final Dictionary properties, final IBundleActivationManager manager) {
		return EXPORTED_SERVICE_NAMES;
	}

	/**
	 * Return the imported service name(s) to be registered by the GpsNmeaAdapter bundle.
	 * @param pid PID.
	 * @param oldProperties old properties.
	 * @param properties properties.
	 * @param manager manager.
	 * @return String[] The imported service names.
	 * @since 1.2
	 */
	public String[] getImportedServiceNames(final String pid, final Dictionary oldProperties, final Dictionary properties, final IBundleActivationManager manager) {
		return IMPORTED_SERVICE_NAMES;
	}

	/**
	 * Return the device service name used by this bundle.
	 * @see org.eclipse.soda.dk.gps.nmea.device.service.GpsNmeaDeviceService
	 * @return String The interest service name.
	 * @since 1.2
	 */
	public String getInterestServiceName() {
		return GpsNmeaDeviceService.SERVICE_NAME;
	}
}
