package org.eclipse.soda.dk.gps.nmea.adapter.service;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import org.eclipse.soda.dk.adapter.service.AdapterService;

/**
 * Global Positioning System (GPS) National Marine Electronics Association (NMEA) Adapter.
 * The device service interface defines the service to be registered for the GpsNmeaAdapter device. 
 * <p>The list of exported services:
 * @see org.eclipse.soda.dk.gps.nmea.adapter.service.GpsNmeaAdapterService
 * @see org.eclipse.soda.dk.adapter.service.AdapterService
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public interface GpsNmeaAdapterService extends AdapterService {
	/**
	 * Define the OSGi service name.
	 * @since 1.0
	 */
	/* Generated field and should not be changed. */
	public static final String SERVICE_NAME = "org.eclipse.soda.dk.gps.nmea.adapter.service.GpsNmeaAdapterService"; //$NON-NLS-1$

	/**
	 * Define the OSGi managed service name.
	 * @since 1.0
	 */
	/* Generated field and should not be changed. */
	public static final String MANAGED_SERVICE_NAME = "org.eclipse.soda.dk.gps.nmea.adapter.managed.GpsNmeaAdapterManaged"; //$NON-NLS-1$

	/**
	 * Define the OSGi factory service name.
	 * @since 1.0
	 */
	/* Generated field and should not be changed. */
	public static final String FACTORY_SERVICE_NAME = "org.eclipse.soda.dk.gps.nmea.adapter.factory.GpsNmeaAdapterFactory"; //$NON-NLS-1$

	/**
	 * Define the GpsNmeaAdapter key.
	 * @since 1.0
	 */
	/* Generated field and should not be changed. */
	public static final String GpsNmeaAdapter = "GpsNmeaAdapter"; //$NON-NLS-1$

	/**
	 * Comprehensive list of all the command identifiers.
	 * @since 1.0
	 */
	/* Generated field and should not be changed. */
	public static final String[] ALL_COMMANDS = new String[] {};

	/**
	 * Comprehensive list of all the signal identifiers.
	 * @since 1.0
	 */
	/* Generated field and should not be changed. */
	public static final String[] ALL_SIGNALS = new String[] {};

	/**
	 * Comprehensive list of all the measurement identifiers.
	 * @since 1.0
	 */
	/* Generated field and should not be changed. */
	public static final String[] ALL_MEASUREMENTS = new String[] {};

	/**
	 * Custom parameter rate configuration key.
	 * @since 1.1
	 */
	/* Generated field and should not be changed. */
	public static final String RATE = "rate"; //$NON-NLS-1$

	/**
	 * Custom parameter rate configuration key.
	 * @deprecated use RATE
	 * @since 1.0
	 */
	/* Generated field and should not be changed. */
	public static final String RATE_KEY = "rate"; //$NON-NLS-1$

	/**
	 * Custom parameter rate configuration default value.
	 * @since 1.1
	 */
	/* Generated field and should not be changed. */
	public static final int RATE_DEFAULT = 0;

	/**
	 * Custom parameter rate configuration default value.
	 * @since 1.1
	 */
	/* Generated field and should not be changed. */
	public static final int DEFAULT_RATE = RATE_DEFAULT;

	/**
	 * Parameter Altitude key.
	 * @since 1.1
	 */
	/* Generated field and should not be changed. */
	public static final String Altitude = "Altitude"; //$NON-NLS-1$

	/**
	 * Parameter Date key.
	 * @since 1.1
	 */
	/* Generated field and should not be changed. */
	public static final String Date = "Date"; //$NON-NLS-1$

	/**
	 * Parameter HorizontalDilutionOfPrecision key.
	 * @since 1.1
	 */
	/* Generated field and should not be changed. */
	public static final String HorizontalDilutionOfPrecision = "HorizontalDilutionOfPrecision"; //$NON-NLS-1$

	/**
	 * Parameter Latitude key.
	 * @since 1.1
	 */
	/* Generated field and should not be changed. */
	public static final String Latitude = "Latitude"; //$NON-NLS-1$

	/**
	 * Parameter Longitude key.
	 * @since 1.1
	 */
	/* Generated field and should not be changed. */
	public static final String Longitude = "Longitude"; //$NON-NLS-1$

	/**
	 * Parameter NumberSatellites key.
	 * @since 1.1
	 */
	/* Generated field and should not be changed. */
	public static final String NumberSatellites = "NumberSatellites"; //$NON-NLS-1$

	/**
	 * Parameter Position key.
	 * @since 1.1
	 */
	/* Generated field and should not be changed. */
	public static final String Position = "Position"; //$NON-NLS-1$

	/**
	 * Parameter Quality key.
	 * @since 1.1
	 */
	/* Generated field and should not be changed. */
	public static final String Quality = "Quality"; //$NON-NLS-1$

	/**
	 * Parameter Status key.
	 * @since 1.1
	 */
	/* Generated field and should not be changed. */
	public static final String Status = "Status"; //$NON-NLS-1$

	/**
	 * Parameter Day key.
	 * @since 1.1
	 */
	/* Generated field and should not be changed. */
	public static final String Day = "Day"; //$NON-NLS-1$

	/**
	 * Parameter Month key.
	 * @since 1.1
	 */
	/* Generated field and should not be changed. */
	public static final String Month = "Month"; //$NON-NLS-1$

	/**
	 * Parameter SpeedKPH key.
	 * @since 1.1
	 */
	/* Generated field and should not be changed. */
	public static final String SpeedKPH = "SpeedKPH"; //$NON-NLS-1$

	/**
	 * Parameter SpeedKnots key.
	 * @since 1.1
	 */
	/* Generated field and should not be changed. */
	public static final String SpeedKnots = "SpeedKnots"; //$NON-NLS-1$

	/**
	 * Parameter Time key.
	 * @since 1.1
	 */
	/* Generated field and should not be changed. */
	public static final String Time = "Time"; //$NON-NLS-1$

	/**
	 * Parameter Track key.
	 * @since 1.1
	 */
	/* Generated field and should not be changed. */
	public static final String Track = "Track"; //$NON-NLS-1$

	/**
	 * Parameter TrackMagnetic key.
	 * @since 1.1
	 */
	/* Generated field and should not be changed. */
	public static final String TrackMagnetic = "TrackMagnetic"; //$NON-NLS-1$

	/**
	 * Parameter Year key.
	 * @since 1.1
	 */
	/* Generated field and should not be changed. */
	public static final String Year = "Year"; //$NON-NLS-1$

	/**
	 * Description of the test.
	 * @since 1.1
	 */
	/* Generated field and should not be changed. */
	public static final String SERVICE_DESCRIPTION = "Global Positioning System (GPS) National Marine Electronics Association (NMEA) Adapter"; //$NON-NLS-1$
}
