package org.eclipse.soda.dk.gps.nmea.adapter.test;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import org.eclipse.soda.dk.adapter.service.AdapterService;
import org.eclipse.soda.dk.adapter.test.AdapterTest;
import org.eclipse.soda.dk.command.service.CommandListener;
import org.eclipse.soda.dk.device.service.DeviceListener;
import org.eclipse.soda.dk.gps.nmea.adapter.GpsNmeaAdapter;
import org.eclipse.soda.dk.gps.nmea.adapter.test.service.GpsNmeaAdapterTestService;
import org.eclipse.soda.dk.measurement.service.MeasurementListener;
import org.eclipse.soda.dk.signal.service.SignalListener;

/**
 * Global Positioning System (GPS) National Marine Electronics Association (NMEA) Adapter Test.
 * The GpsNmeaAdapterTest class implements a set of adaptertest tests.
 * <p>The list of exported services:
 * @see org.eclipse.soda.dk.gps.nmea.adapter.test.service.GpsNmeaAdapterTestService
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class GpsNmeaAdapterTest extends AdapterTest implements GpsNmeaAdapterTestService, Runnable, CommandListener, SignalListener, MeasurementListener, DeviceListener {
	/**
	 * Defines the full class name.
	 * @since 1.0
	 */
	/* Generated field and should not be changed. */
	public static final String CLASS_NAME = "org.eclipse.soda.dk.gps.nmea.adapter.test.GpsNmeaAdapterTest"; //$NON-NLS-1$

	/**
	 * Constructs a new instance of the GpsNmeaAdapterTest class.
	 * @since 1.0
	 */
	public GpsNmeaAdapterTest() {
		super();
	}

	/**
	 * Main method to run tests in a stand alone mode.
	 * @see org.eclipse.soda.dk.gps.nmea.adapter.GpsNmeaAdapter
	 * @param arguments
	 *		The arguments (<code>String[]</code>) parameter.
	 * @since 1.2
	 */
	public static void main(final String[] arguments) {
		final GpsNmeaAdapterTest testCase = new GpsNmeaAdapterTest();
		testCase.run(arguments);
		System.exit(0);
	}

	/**
	 * @see org.eclipse.soda.dk.adapter.test.AdapterTest#getDefaultAdapter()
	 * @return AdapterService The Adapter to be tested.
	 * @throws ClassNotFoundException
	 * @throws IllegalAccessException
	 * @throws InstantiationException
	 * @since 1.2
	 */
	public AdapterService getDefaultAdapter() throws ClassNotFoundException, IllegalAccessException, InstantiationException {
		return new GpsNmeaAdapter();
	}

	/**
	 * Sets user-defined variables to use in the test.
	 * @see org.eclipse.soda.dk.adapter.test.AdapterTest#setup()
	 * @since 1.0
	 */
	public void setup() {
		/* Generated method and should not be changed. */
		super.setup();
		setPriority(getInt("gpsnmeaadaptertest.priority", DEFAULT_PRIORITY)); //$NON-NLS-1$
		setTestCount(getInt("gpsnmeaadaptertest.testcount", DEFAULT_TEST_COUNT)); //$NON-NLS-1$
		setTestDelay(getLong("gpsnmeaadaptertest.testdelay", DEFAULT_TEST_DELAY)); //$NON-NLS-1$
		setTestExecute(getBoolean("gpsnmeaadaptertest.testexecute", DEFAULT_TEST_EXECUTE)); //$NON-NLS-1$
		setTestExecuteRead(getBoolean("gpsnmeaadaptertest.testexecuteread", DEFAULT_TEST_EXECUTE_READ)); //$NON-NLS-1$
		setTestExecuteWrite(getBoolean("gpsnmeaadaptertest.testexecutewrite", DEFAULT_TEST_EXECUTE_WRITE)); //$NON-NLS-1$
		setTestRead(getBoolean("gpsnmeaadaptertest.testread", DEFAULT_TEST_READ)); //$NON-NLS-1$
		setTestTrigger(getBoolean("gpsnmeaadaptertest.testtrigger", DEFAULT_TEST_TRIGGER)); //$NON-NLS-1$
		setTotalTestTime(getLong("gpsnmeaadaptertest.totaltesttime", DEFAULT_TOTAL_TEST_TIME)); //$NON-NLS-1$
	}
}
