package org.eclipse.soda.dk.gps.nmea.adapter.test.bundle;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.util.Hashtable;
import org.eclipse.soda.dk.adapter.service.AdapterService;
import org.eclipse.soda.dk.adapter.test.bundle.AdapterTestBundle;
import org.eclipse.soda.dk.adapter.test.service.AdapterTestService;
import org.eclipse.soda.dk.gps.nmea.adapter.service.GpsNmeaAdapterService;
import org.eclipse.soda.dk.gps.nmea.adapter.test.GpsNmeaAdapterTest;
import org.eclipse.soda.dk.gps.nmea.adapter.test.service.GpsNmeaAdapterTestService;
import org.eclipse.soda.dk.notification.service.NotificationService;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.Constants;

/**
 * Global Positioning System (GPS) National Marine Electronics Association (NMEA) Adapter.
 * <p>The device bundle activator class creates and registers the GpsNmeaAdapterTest device.
 * <p>The list of exported services:
 * @see org.eclipse.soda.dk.gps.nmea.adapter.test.service.GpsNmeaAdapterTestService
 * @see org.eclipse.soda.dk.adapter.service.AdapterService
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class GpsNmeaAdapterTestBundle extends AdapterTestBundle implements BundleActivator {
	/**
	 * Defines the full class name.
	 * @since 1.0
	 */
	/* Generated field and should not be changed. */
	public static final String CLASS_NAME = "org.eclipse.soda.dk.gps.nmea.adapter.test.bundle.GpsNmeaAdapterTestBundle"; //$NON-NLS-1$

	/**
	 * Defines the service name(s) to be registered by the GpsNmeaAdapter bundle.
	 * <table>
	 * <tr>
	 * <td>org.eclipse.soda.dk.gps.nmea.adapter.test.service.GpsNmeaAdapterTestService</td>
	 * </tr>
	 * </table>
	 * @since 1.0
	 */
	/* Generated field and should not be changed. */
	public static final String[] EXPORTED_SERVICE_NAMES = new String[] { GpsNmeaAdapterTestService.SERVICE_NAME };

	/**
	 * Defines the imported service name(s) to be registered by the GpsNmeaAdapterTest bundle.
	 * <table>
	 * <tr>
	 * <td>org.eclipse.soda.dk.gps.nmea.adapter.service.GpsNmeaAdapterService</td>
	 * </tr>
	 * <tr>
	 * <td>org.eclipse.soda.dk.notification.service.NotificationService</td>
	 * </tr>
	 * </table>
	 * @since 1.0
	 */
	/* Generated field and should not be changed. */
	public static final String[] IMPORTED_SERVICE_NAMES = new String[] { GpsNmeaAdapterService.SERVICE_NAME, NotificationService.SERVICE_NAME };

	/**
	 * Gets the properties to be registered with the service(s).
	 * @return Hashtable of properties.
	 * <table width=100%>
	 * <tr>
	 * <td width=50%>org.osgi.framework.Constants.SERVICE_PID</td>
	 * <td width=50%>GpsNmeaAdapterTestService.SERVICE_NAME</td>
	 * </tr>
	 * <tr>
	 * <td width=50%>org.osgi.framework.Constants.SERVICE_DESCRIPTION</td>
	 * <td width=50%>GpsNmeaAdapterTestService.SERVICE_DESCRIPTION</td>
	 * </tr>
	 * <tr>
	 * <td width=50%>org.osgi.framework.Constants.SERVICE_RANKING</td>
	 * <td width=50%>6</td>
	 * </tr>
	 * <tr>
	 * <td width=50%>org.osgi.framework.Constants.SERVICE_VENDOR</td>
	 * <td width=50%>IBM</td>
	 * </tr>
	 * </table>
	 * @since 1.2
	 */
	public Hashtable createProperties() {
		/* Generated method and should not be changed. */
		final Hashtable properties = super.createProperties();
		properties.put(Constants.SERVICE_PID, GpsNmeaAdapterTestService.SERVICE_NAME);
		properties.put(Constants.SERVICE_DESCRIPTION, GpsNmeaAdapterTestService.SERVICE_DESCRIPTION);
		properties.put(Constants.SERVICE_RANKING, "6"); //$NON-NLS-1$
		properties.put(Constants.SERVICE_VENDOR, "IBM"); //$NON-NLS-1$
		return properties;
	}

	/**
	 * Creates the test for the specified adapter.
	 * @see org.eclipse.soda.dk.gps.nmea.adapter.test.GpsNmeaAdapterTest
	 * @param adapter AdapterService
	 * @return org.eclipse.soda.dk.adapter.test.service.AdapterTestService The adapter test.
	 * @since 1.2
	 */
	public AdapterTestService createService(final AdapterService adapter) {
		final GpsNmeaAdapterTest test = new GpsNmeaAdapterTest();
		test.setAdapter(adapter);
		return test;
	}

	/**
	 * Return the exported service name(s) to be registered by the GpsNmeaAdapter bundle.
	 * @return String[] The exported service name(s).
	 * @since 1.2
	 */
	public String[] getExportedServiceNames() {
		return EXPORTED_SERVICE_NAMES;
	}

	/**
	 * Return the imported service name(s) to be registered by the GpsNmeaAdapterTest bundle.
	 * @return String[] The imported service names.
	 * @since 1.2
	 */
	public String[] getImportedServiceNames() {
		return IMPORTED_SERVICE_NAMES;
	}

	/**
	 * Gets the adapter service name to be tested.
	 * @see org.eclipse.soda.dk.gps.nmea.adapter.service.GpsNmeaAdapterService
	 * @return String The interest service name.
	 * @since 1.2
	 */
	public String getInterestServiceName() {
		return org.eclipse.soda.dk.gps.nmea.adapter.service.GpsNmeaAdapterService.SERVICE_NAME;
	}
}
