package org.eclipse.soda.dk.gps.nmea.device.messages;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import org.eclipse.soda.dk.filter.SimpleFilter;
import org.eclipse.soda.dk.filter.service.FilterService;
import org.eclipse.soda.dk.gps.nmea.device.service.GpsNmeaDeviceService;
import org.eclipse.soda.dk.message.TokenMessage;
import org.eclipse.soda.dk.message.service.MessageService;
import org.eclipse.soda.dk.parameter.FieldParameter;
import org.eclipse.soda.dk.parameter.MapParameters;
import org.eclipse.soda.dk.parameter.service.ParameterService;

/**
 * Global Positioning System (GPS) National Marine Electronics Association (NMEA) Device.
 * 
 *  The device message interface defines the named messages for the GpsNmeaDevice device. 
 * <p>The list of exported services:
 * @see org.eclipse.soda.dk.gps.nmea.device.service.GpsNmeaDeviceService
 * @see org.eclipse.soda.dk.device.service.DeviceService
 *  
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class GpsNmeaDeviceMessages extends Object {
	/**
	 * Defines the full class name.
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String CLASS_NAME = "org.eclipse.soda.dk.gps.nmea.device.messages.GpsNmeaDeviceMessages"; //$NON-NLS-1$

	/**
	 * Defines the Filter0 filter.
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private static final FilterService Filter0 = new SimpleFilter(0, 6);

	/**
	 * Defines the GPGLLMessage message <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Position</li>
	 * <li>Latitude</li>
	 * <li>Longitude</li>
	 * <li>Time</li>
	 * <li>Status</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private static final MessageService GPGLLMessage = new TokenMessage(
	// $GPGLL
			new byte[] { '$', 'G', 'P', 'G', 'L', 'L' } // 36 71 80 71 76 76 
			, getFilter0(), new MapParameters("", //$NON-NLS-1$
					new ParameterService[] { new FieldParameter(GpsNmeaDeviceService.Position, null, "Position"), //$NON-NLS-1$
							new FieldParameter(GpsNmeaDeviceService.Latitude, null, "Latitude"), //$NON-NLS-1$
							new FieldParameter(GpsNmeaDeviceService.Longitude, null, "Longitude"), //$NON-NLS-1$
							new FieldParameter(GpsNmeaDeviceService.Time, null, "5", //$NON-NLS-1$
									ParameterService.NSTRING), new FieldParameter(GpsNmeaDeviceService.Status, null, "6") //$NON-NLS-1$
					}), ",*\r\n"); //$NON-NLS-1$

	/**
	 * Defines the GPRMCMessage message <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Time</li>
	 * <li>Status</li>
	 * <li>Position</li>
	 * <li>Latitude</li>
	 * <li>Longitude</li>
	 * <li>SpeedKnots</li>
	 * <li>Track</li>
	 * <li>Date</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private static final MessageService GPRMCMessage = new TokenMessage(
	// $GPRMC
			new byte[] { '$', 'G', 'P', 'R', 'M', 'C' } // 36 71 80 82 77 67 
			, getFilter0(), new MapParameters("", //$NON-NLS-1$
					new ParameterService[] { new FieldParameter(GpsNmeaDeviceService.Time, null, "1", //$NON-NLS-1$
							ParameterService.NSTRING), new FieldParameter(GpsNmeaDeviceService.Status, null, "2"), //$NON-NLS-1$
							new FieldParameter(GpsNmeaDeviceService.Position, null, "Position"), //$NON-NLS-1$
							new FieldParameter(GpsNmeaDeviceService.Latitude, null, "Latitude"), //$NON-NLS-1$
							new FieldParameter(GpsNmeaDeviceService.Longitude, null, "Longitude"), //$NON-NLS-1$
							new FieldParameter(GpsNmeaDeviceService.SpeedKnots, null, "7", //$NON-NLS-1$
									ParameterService.NSTRING), new FieldParameter(GpsNmeaDeviceService.Track, null, "8", //$NON-NLS-1$
									ParameterService.NSTRING), new FieldParameter(GpsNmeaDeviceService.Date, null, "9") //$NON-NLS-1$
					}), ",*\r\n"); //$NON-NLS-1$

	/**
	 * Defines the GPGGAMessage message <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Time</li>
	 * <li>Position</li>
	 * <li>Latitude</li>
	 * <li>Longitude</li>
	 * <li>Quality</li>
	 * <li>NumberSatellites</li>
	 * <li>HorizontalDilutionOfPrecision</li>
	 * <li>Altitude</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private static final MessageService GPGGAMessage = new TokenMessage(
	// $GPGGA
			new byte[] { '$', 'G', 'P', 'G', 'G', 'A' } // 36 71 80 71 71 65 
			, getFilter0(), new MapParameters("", //$NON-NLS-1$
					new ParameterService[] { new FieldParameter(GpsNmeaDeviceService.Time, null, "1", //$NON-NLS-1$
							ParameterService.NSTRING), new FieldParameter(GpsNmeaDeviceService.Position, null, "Position"), //$NON-NLS-1$
							new FieldParameter(GpsNmeaDeviceService.Latitude, null, "Latitude"), //$NON-NLS-1$
							new FieldParameter(GpsNmeaDeviceService.Longitude, null, "Longitude"), //$NON-NLS-1$
							new FieldParameter(GpsNmeaDeviceService.Quality, null, "6", //$NON-NLS-1$
									ParameterService.NSTRING), new FieldParameter(GpsNmeaDeviceService.NumberSatellites, null, "7", //$NON-NLS-1$
									ParameterService.NSTRING), new FieldParameter(GpsNmeaDeviceService.HorizontalDilutionOfPrecision, null, "8", //$NON-NLS-1$
									ParameterService.NSTRING), new FieldParameter(GpsNmeaDeviceService.Altitude, null, "9", //$NON-NLS-1$
									ParameterService.NSTRING) }), ",*\r\n"); //$NON-NLS-1$

	/**
	 * Defines the GPVTGMessage message <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Track</li>
	 * <li>TrackMagnetic</li>
	 * <li>SpeedKnots</li>
	 * <li>SpeedKPH</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private static final MessageService GPVTGMessage = new TokenMessage(
	// $GPVTG
			new byte[] { '$', 'G', 'P', 'V', 'T', 'G' } // 36 71 80 86 84 71 
			, getFilter0(), new MapParameters("", //$NON-NLS-1$
					new ParameterService[] { new FieldParameter(GpsNmeaDeviceService.Track, null, "1", //$NON-NLS-1$
							ParameterService.NSTRING), new FieldParameter(GpsNmeaDeviceService.TrackMagnetic, null, "3", //$NON-NLS-1$
							ParameterService.NSTRING), new FieldParameter(GpsNmeaDeviceService.SpeedKnots, null, "5", //$NON-NLS-1$
							ParameterService.NSTRING), new FieldParameter(GpsNmeaDeviceService.SpeedKPH, null, "7", //$NON-NLS-1$
							ParameterService.NSTRING) }), ",*\r\n"); //$NON-NLS-1$

	/**
	 * Defines the GPZDAMessage message <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Time</li>
	 * <li>Day</li>
	 * <li>Month</li>
	 * <li>Year</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private static final MessageService GPZDAMessage = new TokenMessage(
	// $GPZDA
			new byte[] { '$', 'G', 'P', 'Z', 'D', 'A' } // 36 71 80 90 68 65 
			, getFilter0(), new MapParameters("", //$NON-NLS-1$
					new ParameterService[] { new FieldParameter(GpsNmeaDeviceService.Time, null, "1", //$NON-NLS-1$
							ParameterService.NSTRING), new FieldParameter(GpsNmeaDeviceService.Day, null, "2", //$NON-NLS-1$
							ParameterService.NSTRING), new FieldParameter(GpsNmeaDeviceService.Month, null, "3", //$NON-NLS-1$
							ParameterService.NSTRING), new FieldParameter(GpsNmeaDeviceService.Year, null, "4", //$NON-NLS-1$
							ParameterService.NSTRING) }), ",*\r\n"); //$NON-NLS-1$

	/**
	 * Gets the Filter0 value.
	 * @return FilterService The Filter0 message
	 * @since 1.0
	 */
	public static FilterService getFilter0() {
		/* Generated method and should not be changed. */
		return Filter0;
	}

	/**
	 * Gets the GPGLLMessage value.
	 * @return MessageService The GPGLLMessage message
	 * @since 1.0
	 */
	public static MessageService getGPGLLMessage() {
		/* Generated method and should not be changed. */
		return GPGLLMessage;
	}

	/**
	 * Gets the GPRMCMessage value.
	 * @return MessageService The GPRMCMessage message
	 * @since 1.0
	 */
	public static MessageService getGPRMCMessage() {
		/* Generated method and should not be changed. */
		return GPRMCMessage;
	}

	/**
	 * Gets the GPGGAMessage value.
	 * @return MessageService The GPGGAMessage message
	 * @since 1.0
	 */
	public static MessageService getGPGGAMessage() {
		/* Generated method and should not be changed. */
		return GPGGAMessage;
	}

	/**
	 * Gets the GPVTGMessage value.
	 * @return MessageService The GPVTGMessage message
	 * @since 1.0
	 */
	public static MessageService getGPVTGMessage() {
		/* Generated method and should not be changed. */
		return GPVTGMessage;
	}

	/**
	 * Gets the GPZDAMessage value.
	 * @return MessageService The GPZDAMessage message
	 * @since 1.0
	 */
	public static MessageService getGPZDAMessage() {
		/* Generated method and should not be changed. */
		return GPZDAMessage;
	}
}
