package org.eclipse.soda.dk.gps.nmea.device.test;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import org.eclipse.soda.dk.command.service.CommandListener;
import org.eclipse.soda.dk.device.service.DeviceListener;
import org.eclipse.soda.dk.device.service.DeviceService;
import org.eclipse.soda.dk.device.test.DeviceTest;
import org.eclipse.soda.dk.gps.nmea.device.GpsNmeaDevice;
import org.eclipse.soda.dk.gps.nmea.device.test.service.GpsNmeaDeviceTestService;
import org.eclipse.soda.dk.measurement.service.MeasurementListener;
import org.eclipse.soda.dk.signal.service.SignalListener;

/**
 * Global Positioning System (GPS) National Marine Electronics Association (NMEA) Device Test.
 * 
 *  The GpsNmeaDeviceTest class implements a set of devicetest tests.
 * <p>The list of exported services:
 * @see org.eclipse.soda.dk.gps.nmea.device.test.service.GpsNmeaDeviceTestService
 *  
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class GpsNmeaDeviceTest extends DeviceTest implements GpsNmeaDeviceTestService, Runnable, CommandListener, SignalListener, MeasurementListener, DeviceListener {
	/**
	 * Defines the full class name.
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String CLASS_NAME = "org.eclipse.soda.dk.gps.nmea.device.test.GpsNmeaDeviceTest"; //$NON-NLS-1$

	/**
	 * Constructs a new instance of the GpsNmeaDeviceTest class.
	 * @since 1.0
	 */
	public GpsNmeaDeviceTest() {
		/* Generated method and should not be changed. */
		super();
	}

	/**
	 * Main method to run tests in a stand alone mode.
	 * 
	 * @param arguments
	 * @see org.eclipse.soda.dk.gps.nmea.device.GpsNmeaDevice
	 * @since 1.0
	 */
	public static void main(final String[] arguments) {
		/* Generated method and should not be changed. */
		/*
		The following will make sure that we have no references to the specific device class
		when running as a bundle.
		*/
		final GpsNmeaDeviceTest testCase = new GpsNmeaDeviceTest();
		testCase.run(arguments);
		System.exit(0);
	}

	/**
	 * Gets the default DeviceService to be tested.
	 * 
	 * @return DeviceService The Device to be tested.
	 * @throws ClassNotFoundException
	 * @throws IllegalAccessException
	 * @throws InstantiationException
	 * @see org.eclipse.soda.dk.device.test.DeviceTest#getDefaultDevice()
	 * @since 1.0
	 */
	public DeviceService getDefaultDevice() throws ClassNotFoundException, IllegalAccessException, InstantiationException {
		/* Generated method and should not be changed. */
		return new GpsNmeaDevice();
	}

	/**
	 * Sets user-defined variables to use in the test.
	 * 
	 * @see org.eclipse.soda.dk.device.test.DeviceTest#setup()
	 * @since 1.0
	 */
	public void setup() {
		/* Generated method and should not be changed. */
		super.setup();
		setPriority(getInt("gpsnmeadevicetest.priority", PRIORITY_DEFAULT)); //$NON-NLS-1$
		setTestCount(getInt("gpsnmeadevicetest.testcount", TEST_COUNT_DEFAULT)); //$NON-NLS-1$
		setTestDelay(getLong("gpsnmeadevicetest.testdelay", TEST_DELAY_DEFAULT)); //$NON-NLS-1$
		setTestExecute(getBoolean("gpsnmeadevicetest.testexecute", TEST_EXECUTE_DEFAULT)); //$NON-NLS-1$
		setTestExecuteRead(getBoolean("gpsnmeadevicetest.testexecuteread", TEST_EXECUTE_READ_DEFAULT)); //$NON-NLS-1$
		setTestExecuteWrite(getBoolean("gpsnmeadevicetest.testexecutewrite", TEST_EXECUTE_WRITE_DEFAULT)); //$NON-NLS-1$
		setTestRead(getBoolean("gpsnmeadevicetest.testread", TEST_READ_DEFAULT)); //$NON-NLS-1$
		setTestTrigger(getBoolean("gpsnmeadevicetest.testtrigger", TEST_TRIGGER_DEFAULT)); //$NON-NLS-1$
		setTotalTestTime(getLong("gpsnmeadevicetest.totaltesttime", TOTAL_TEST_TIME_DEFAULT)); //$NON-NLS-1$
	}
}
