package org.eclipse.soda.dk.gps.nmea.position.profile;

/*************************************************************************
 * Copyright (c) 2008, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.util.Hashtable;
import java.util.Map;

import org.eclipse.soda.dk.adapter.service.AdapterService;
import org.eclipse.soda.dk.data.Degree;
import org.eclipse.soda.dk.device.service.DeviceService;
import org.eclipse.soda.dk.gps.nmea.device.service.GpsNmeaDeviceService;
import org.eclipse.soda.dk.gps.nmea.position.profile.service.GpsNmeaPositionProfileService;
import org.eclipse.soda.dk.position.profile.PositionProfile;
import org.eclipse.soda.dk.position.profile.service.PositionProfileService;
import org.eclipse.soda.dk.profile.service.ProfileService;
import org.eclipse.soda.dk.signal.service.SignalService;

/**
 * Gps Nmea Profile.
 * 
 * The GpsNmeaPositionProfile class implements the GpsNmeaPositionProfileService and provides the controls for the profile.
 * <p>The list of exported services:
 * @see org.eclipse.soda.dk.gps.nmea.position.profile.service.GpsNmeaPositionProfileService
 * @see org.eclipse.soda.dk.profile.service.ProfileService
 *  
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class GpsNmeaPositionProfile extends PositionProfile implements ProfileService, GpsNmeaPositionProfileService {
	/**
	 * Defines the full class name.
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String CLASS_NAME = "org.eclipse.soda.dk.gps.nmea.position.profile.GpsNmeaPositionProfile"; //$NON-NLS-1$

	/**
	 * Defines the GPGLL signalref.
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	protected SignalService gpsNmeaDeviceServiceGPGLL;

	/**
	 * Defines the GPGGA signalref.
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	protected SignalService gpsNmeaDeviceServiceGPGGA;

	/**
	 * Define adapter.
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	private AdapterService adapter;

	/**
	 * Constructs a new instance of the GpsNmeaPositionProfile class.
	 * @since 1.1
	 */
	public GpsNmeaPositionProfile() {
		/* Generated method and should not be changed. */
		super();
		setKey(getDefaultKey()); //The super class defines the common measurements
		initialize();
	}

	/**
	 * Set device.
	 * @param device device.
	 * @since 1.1
	 */
	public void setDevice(final DeviceService device) {
		/* Generated method and should not be changed. */
		if (getDevice() != null) {
			if (this.gpsNmeaDeviceServiceGPGLL != null) {
				this.gpsNmeaDeviceServiceGPGLL.removeSignalListener(this);
			}
			if (this.gpsNmeaDeviceServiceGPGGA != null) {
				this.gpsNmeaDeviceServiceGPGGA.removeSignalListener(this);
			}
		}
		if (device != null) {
			this.gpsNmeaDeviceServiceGPGLL = device.getSignal(GpsNmeaDeviceService.GPGLL);
			initializeSignal(this.gpsNmeaDeviceServiceGPGLL);
			this.gpsNmeaDeviceServiceGPGGA = device.getSignal(GpsNmeaDeviceService.GPGGA);
			initializeSignal(this.gpsNmeaDeviceServiceGPGGA);
		}
		super.setDevice(device);
	}

	/**
	 * Signal occurred.
	 * @param source source.
	 * @param timestamp time stamp.
	 * @param data data.
	 * @since 1.1
	 */
	public void signalOccurred(final SignalService source, final Object timestamp, final Object data) {
		/* Generated method and should not be changed. */
		if (this.gpsNmeaDeviceServiceGPGLL == source) { /* check referenced signal */
			handleGpsNmeaDeviceServiceGPGLL(source, timestamp, data);
			return;
		}
		if (this.gpsNmeaDeviceServiceGPGGA == source) { /* check referenced signal */
			handleGpsNmeaDeviceServiceGPGGA(source, timestamp, data);
			return;
		}
		super.signalOccurred(source, timestamp, data);
	}

	/**
	 * Gets the default key of the profile.
	 * @return String The default key
	 * @since 1.1
	 */
	public String getDefaultKey() {
		/* Generated method and should not be changed. */
		return GpsNmeaPositionProfileService.GpsNmeaPositionProfile;
	}

	/**
	 * Gets the default DeviceService.
	 * @return DeviceService The default DeviceService.
	 * @since 1.1
	 */
	public DeviceService getDefaultDevice() {
		/* Generated method and should not be changed. */
		return (DeviceService) loadService(DeviceService.SERVICE_NAME, "org.eclipse.soda.dk.gps.nmea.device.GpsNmeaDevice"); //$NON-NLS-1$
	}

	/**
	 * Is device needed.
	 * @return The results of this method.
	 * @since 1.1
	 */
	public boolean isDeviceNeeded() {
		/* Generated method and should not be changed. */
		return true;
	}

	/**
	 * Create and initialize the controls for this profile.
	 * @since 1.1
	 */
	private void initialize() {
		/* Generated method and should not be changed. */
	}

	/**
	 * @see org.eclipse.soda.dk.device.Container#setup()
	 * @since 1.2
	 */
	public void setup() {
		/* Generated method and should not be changed. */
		super.setup();
		setNotificationPriority(getInt("gpsnmeapositionprofile.notificationpriority", getNotificationPriority())); //$NON-NLS-1$
	}

	/**
	 * Gets the get adapter value.
	 * @return The adapter value.
	 * @since 1.1
	 */
	public AdapterService getAdapter() {
		/* Generated method and should not be changed. */
		return this.adapter;
	}

	/**
	 * Set adapter.
	 * @param adapter adapter.
	 * @since 1.1
	 */
	public void setAdapter(final AdapterService adapter) {
		/* Generated method and should not be changed. */
		this.adapter = adapter;
	}

	/**
	 * Is adapter needed.
	 * @return The results of this method.
	 * @since 1.1
	 */
	public boolean isAdapterNeeded() {
		/* Generated method and should not be changed. */
		return true;
	}

	/**
	 * Handle gps nmea device service gpgga with the specified source, timestamp and data parameters.
	 * @param source
	 *		The source (<code>SignalService</code>) parameter.
	 * @param timestamp
	 *		The time stamp (<code>Object</code>) parameter.
	 * @param data
	 *		The data (<code>Object</code>) parameter.
	 */
	protected void handleGpsNmeaDeviceServiceGPGGA(final SignalService source, final Object timestamp, final Object data) {
		handleSignal(timestamp, data);
	}

	/**
	 * Handle gps nmea device service gpgll with the specified source, timestamp and data parameters.
	 * @param source
	 *		The source (<code>SignalService</code>) parameter.
	 * @param timestamp
	 *		The time stamp (<code>Object</code>) parameter.
	 * @param data
	 *		The data (<code>Object</code>) parameter.
	 */
	protected void handleGpsNmeaDeviceServiceGPGLL(final SignalService source, final Object timestamp, final Object data) {
		handleSignal(timestamp, data);
	}

	/**
	 * Handle signal with the specified timestamp and data parameters.
	 * @param timestamp
	 *		The time stamp (<code>Object</code>) parameter.
	 * @param data
	 *		The data (<code>Object</code>) parameter.
	 */
	public void handleSignal(final Object timestamp, final Object data) {
		if (data instanceof Map) {
			final Map map = (Map) data;
			final Map coordinateMap = new Hashtable();
			final Object latitude = map.get(GpsNmeaDeviceService.Latitude);
			if (latitude != null) {
				if (latitude instanceof Degree) {
					final Degree degree = (Degree) latitude;
					coordinateMap.put(PositionProfileService.LATITUDE_DATA_KEY, new Double(degree.doubleValue()));
				} else {
					coordinateMap.put(PositionProfileService.LATITUDE_DATA_KEY, latitude);
				}
			}
			final Object longitude = map.get(GpsNmeaDeviceService.Longitude);
			if (longitude != null) {
				if (longitude instanceof Degree) {
					final Degree degree = (Degree) longitude;
					coordinateMap.put(PositionProfileService.LONGITUDE_DATA_KEY, new Double(degree.doubleValue()));
				} else {
					coordinateMap.put(PositionProfileService.LONGITUDE_DATA_KEY, longitude);
				}
			}
			final Object altitude = map.get(GpsNmeaDeviceService.Altitude);
			if (altitude != null) {
				coordinateMap.put(PositionProfileService.ALTITUDE_DATA_KEY, altitude);
			}
			this.coordinate.setValue(coordinateMap, timestamp);
		}
	}
}
