package org.eclipse.soda.dk.gps.nmea.position.profile.managed;

/*************************************************************************
 * Copyright (c) 2008, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.util.Dictionary;
import java.util.Hashtable;

import org.eclipse.soda.dk.adapter.service.AdapterService;
import org.eclipse.soda.dk.device.service.DeviceService;
import org.eclipse.soda.dk.gps.nmea.adapter.service.GpsNmeaAdapterService;
import org.eclipse.soda.dk.gps.nmea.device.service.GpsNmeaDeviceService;
import org.eclipse.soda.dk.gps.nmea.position.profile.GpsNmeaPositionProfile;
import org.eclipse.soda.dk.gps.nmea.position.profile.service.GpsNmeaPositionProfileService;
import org.eclipse.soda.dk.notification.service.NotificationService;
import org.eclipse.soda.dk.position.profile.service.PositionProfileService;
import org.eclipse.soda.dk.profile.managed.ProfileManaged;
import org.eclipse.soda.dk.profile.service.ProfileService;
import org.eclipse.soda.sat.core.framework.interfaces.IBundleActivationManager;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.Constants;

/**
 * Gps Nmea Profile.
 * <p>The device bundle activator class creates and registers the GpsNmeaPositionProfile device.
 * <p>The list of exported services:
 * @see org.eclipse.soda.dk.gps.nmea.position.profile.service.GpsNmeaPositionProfileService
 * @see org.eclipse.soda.dk.profile.service.ProfileService
 *  
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class GpsNmeaPositionProfileManaged extends ProfileManaged implements BundleActivator {
	/**
	 * Defines the full class name.
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String CLASS_NAME = "org.eclipse.soda.dk.gps.nmea.position.profile.managed.GpsNmeaPositionProfileManaged"; //$NON-NLS-1$

	/**
	 * Defines the service name(s) to be registered by the GpsNmeaPositionProfile bundle.
	 * <table>
	 * <tr>
	 * <td>org.eclipse.soda.dk.profile.service.ProfileService</td>
	 * </tr>
	 * <tr>
	 * <td>org.eclipse.soda.dk.position.profile.service.PositionProfileService</td>
	 * </tr>
	 * <tr>
	 * <td>org.eclipse.soda.dk.gps.nmea.position.profile.service.GpsNmeaPositionProfileService</td>
	 * </tr>
	 * </table>
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String[] EXPORTED_SERVICE_NAMES = new String[] { ProfileService.SERVICE_NAME, PositionProfileService.SERVICE_NAME, GpsNmeaPositionProfileService.SERVICE_NAME };

	/**
	 * Defines the imported service name(s) to be registered by the GpsNmeaPositionProfile bundle.
	 * <table>
	 * <tr>
	 * <td>org.eclipse.soda.dk.gps.nmea.device.service.GpsNmeaDeviceService</td>
	 * </tr>
	 * <tr>
	 * <td>org.eclipse.soda.dk.gps.nmea.adapter.service.GpsNmeaAdapterService</td>
	 * </tr>
	 * <tr>
	 * <td>org.eclipse.soda.dk.notification.service.NotificationService</td>
	 * </tr>
	 * </table>
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String[] IMPORTED_SERVICE_NAMES = new String[] { GpsNmeaDeviceService.SERVICE_NAME, GpsNmeaAdapterService.SERVICE_NAME, NotificationService.SERVICE_NAME };

	/**
	 * Gets the properties to be registered with the service(s).
	 * @return Hashtable of properties.
	 * 
	 * <table width=100%>
	 * <tr>
	 * <td width=50%>org.osgi.framework.Constants.SERVICE_PID</td>
	 * <td width=50%>GpsNmeaPositionProfileService.SERVICE_NAME</td>
	 * </tr>
	 * <tr>
	 * <td width=50%>org.osgi.framework.Constants.SERVICE_DESCRIPTION</td>
	 * <td width=50%>GpsNmeaPositionProfileService.SERVICE_DESCRIPTION</td>
	 * </tr>
	 * <tr>
	 * <td width=50%>org.osgi.framework.Constants.SERVICE_RANKING</td>
	 * <td width=50%>6</td>
	 * </tr>
	 * <tr>
	 * <td width=50%>org.osgi.framework.Constants.SERVICE_VENDOR</td>
	 * <td width=50%>IBM</td>
	 * </tr>
	 * </table>
	 * @since 1.1
	 */
	public Hashtable createProperties() {
		/* Generated method and should not be changed. */
		final Hashtable properties = super.createProperties();
		properties.put(Constants.SERVICE_PID, GpsNmeaPositionProfileService.SERVICE_NAME);
		properties.put(Constants.SERVICE_DESCRIPTION, GpsNmeaPositionProfileService.SERVICE_DESCRIPTION);
		properties.put(Constants.SERVICE_RANKING, "6"); //$NON-NLS-1$
		properties.put(Constants.SERVICE_VENDOR, "IBM"); //$NON-NLS-1$
		return properties;
	}

	/**
	 * Create profile service with the specified manager parameter and return the ProfileService result.
	 * 
	 * @param manager	The manager (<code>IBundleActivationManager</code>) parameter.
	 * @return Results of the create service (<code>ProfileService</code>) value.
	 * @see org.eclipse.soda.dk.gps.nmea.position.profile.GpsNmeaPositionProfile
	 * @since 1.1
	 */
	public ProfileService createService(final IBundleActivationManager manager) {
		/* Generated method and should not be changed. */
		final GpsNmeaPositionProfile profile = new GpsNmeaPositionProfile();
		final String interestServiceName = getInterestServiceName();
		final DeviceService device = (DeviceService) manager.getImportedService(interestServiceName);
		profile.setDevice(device);
		final String adapterServiceName = getAdapterServiceName();
		final AdapterService adapter = (AdapterService) manager.getImportedService(adapterServiceName);
		profile.setAdapter(adapter);
		return profile;
	}

	/**
	 * Return the adapter service name used by this bundle.
	 * 
	 * @return String The adapter service name.
	 * @see org.eclipse.soda.dk.gps.nmea.adapter.service.GpsNmeaAdapterService
	 * @since 1.1
	 */
	public String getAdapterServiceName() {
		/* Generated method and should not be changed. */
		return GpsNmeaAdapterService.SERVICE_NAME;
	}

	/**
	 * Return the exported service name(s) to be registered by the GpsNmeaPositionProfile bundle.
	 * @return String[] The exported service name(s).
	 * @param pid PID.
	 * @param oldProperties old properties.
	 * @param properties properties.
	 * @param manager manager.
	 * @since 1.1
	 */
	public String[] getExportedServiceNames(final String pid, final Dictionary oldProperties, final Dictionary properties, final IBundleActivationManager manager) {
		/* Generated method and should not be changed. */
		return EXPORTED_SERVICE_NAMES;
	}

	/**
	 * Return the imported service name(s) to be registered by the GpsNmeaPositionProfile bundle.
	 * @return String[] The imported service names.
	 * @param pid PID.
	 * @param oldProperties old properties.
	 * @param properties properties.
	 * @param manager manager.
	 * @since 1.1
	 */
	public String[] getImportedServiceNames(final String pid, final Dictionary oldProperties, final Dictionary properties, final IBundleActivationManager manager) {
		/* Generated method and should not be changed. */
		return IMPORTED_SERVICE_NAMES;
	}

	/**
	 * Return the device service name used by this bundle.
	 * 
	 * @return String The interest service name.
	 * @see org.eclipse.soda.dk.gps.nmea.device.service.GpsNmeaDeviceService
	 * @since 1.1
	 */
	public String getInterestServiceName() {
		/* Generated method and should not be changed. */
		return GpsNmeaDeviceService.SERVICE_NAME;
	}
}
