package org.eclipse.soda.dk.gps.nmea.position.profile.service;

/*************************************************************************
 * Copyright (c) 2008, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import org.eclipse.soda.dk.notification.service.NotificationService;
import org.eclipse.soda.dk.position.profile.service.PositionProfileService;
import org.eclipse.soda.dk.profile.service.ProfileService;

/**
 * Gps Nmea Profile.
 * 
 *  The device service interface defines the service to be registered for the GpsNmeaPositionProfile device. 
 *  
 * <p>The list of exported services:
 * @see org.eclipse.soda.dk.gps.nmea.position.profile.service.GpsNmeaPositionProfileService
 * @see org.eclipse.soda.dk.profile.service.ProfileService
 *  
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public interface GpsNmeaPositionProfileService extends ProfileService, PositionProfileService {
	/**
	 * Define the OSGi service name.
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String SERVICE_NAME = "org.eclipse.soda.dk.gps.nmea.position.profile.service.GpsNmeaPositionProfileService"; //$NON-NLS-1$

	/**
	 * Define the OSGi managed service name.
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String MANAGED_SERVICE_NAME = "org.eclipse.soda.dk.gps.nmea.position.profile.managed.GpsNmeaPositionProfileManaged"; //$NON-NLS-1$

	/**
	 * Define the OSGi factory service name.
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String FACTORY_SERVICE_NAME = "org.eclipse.soda.dk.gps.nmea.position.profile.factory.GpsNmeaPositionProfileFactory"; //$NON-NLS-1$

	/**
	 * Define the GpsNmeaPositionProfile key.
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String GpsNmeaPositionProfile = "GpsNmeaPositionProfile"; //$NON-NLS-1$

	/**
	 * Comprehensive list of all the command identifiers.
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String[] ALL_COMMANDS = new String[] {};

	/**
	 * Comprehensive list of all the signal identifiers.
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String[] ALL_SIGNALS = new String[] {};

	/**
	 * Comprehensive list of all the measurement identifiers.
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String[] ALL_MEASUREMENTS = new String[] {};

	/**
	 * Description of the test.
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String SERVICE_DESCRIPTION = "Gps Nmea Profile"; //$NON-NLS-1$

	/**
	 * Define the Position Profile Status measurement.
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String Status = "PositionProfile/Status"; //$NON-NLS-1$

	/**
	 * Define the Position Profile Status measurement.
	 * @see #Status
	 * The value of this field is "<i>prefix/<i><b>PositionProfile/Status</b>"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String STATUS_EXTERNAL_KEY = "PositionProfile/Status"; //$NON-NLS-1$

	/**
	 * Define the Position Profile Status measurement.
	 * @see #Status
	 * The value of this field is "<i>prefix/<i><b>PositionProfile/Status</b>/get"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String STATUS_GET_EXTERNAL_KEY = GpsNmeaPositionProfileService.STATUS_EXTERNAL_KEY + NotificationService.GET_EXTERNAL_KEY;

	/**
	 * Define the Position Profile Status measurement.
	 * @see #Status
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>PositionProfile/Status</b>/error"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String STATUS_ERROR_EXTERNAL_KEY = GpsNmeaPositionProfileService.STATUS_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Define the Position Profile Configuration measurement.
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String Configuration = "PositionProfile/Configuration"; //$NON-NLS-1$

	/**
	 * Define the Position Profile Configuration measurement.
	 * @see #Configuration
	 * The value of this field is "<i>prefix/<i><b>PositionProfile/Configuration</b>"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String CONFIGURATION_EXTERNAL_KEY = "PositionProfile/Configuration"; //$NON-NLS-1$

	/**
	 * Define the Position Profile Configuration measurement.
	 * @see #Configuration
	 * The value of this field is "<i>prefix/<i><b>PositionProfile/Configuration</b>/get"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String CONFIGURATION_GET_EXTERNAL_KEY = GpsNmeaPositionProfileService.CONFIGURATION_EXTERNAL_KEY + NotificationService.GET_EXTERNAL_KEY;

	/**
	 * Define the Position Profile Configuration measurement.
	 * @see #Configuration
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>PositionProfile/Configuration</b>/error"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String CONFIGURATION_ERROR_EXTERNAL_KEY = GpsNmeaPositionProfileService.CONFIGURATION_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Define the Position Profile Capabilities measurement.
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String Capabilities = "PositionProfile/Capabilities"; //$NON-NLS-1$

	/**
	 * Define the Position Profile Capabilities measurement.
	 * @see #Capabilities
	 * The value of this field is "<i>prefix/<i><b>PositionProfile/Capabilities</b>"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String CAPABILITIES_EXTERNAL_KEY = "PositionProfile/Capabilities"; //$NON-NLS-1$

	/**
	 * Define the Position Profile Capabilities measurement.
	 * @see #Capabilities
	 * The value of this field is "<i>prefix/<i><b>PositionProfile/Capabilities</b>/get"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String CAPABILITIES_GET_EXTERNAL_KEY = GpsNmeaPositionProfileService.CAPABILITIES_EXTERNAL_KEY + NotificationService.GET_EXTERNAL_KEY;

	/**
	 * Define the Position Profile Capabilities measurement.
	 * @see #Capabilities
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>PositionProfile/Capabilities</b>/error"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String CAPABILITIES_ERROR_EXTERNAL_KEY = GpsNmeaPositionProfileService.CAPABILITIES_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Define the Position Profile Metrics measurement.
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String Metrics = "PositionProfile/Metrics"; //$NON-NLS-1$

	/**
	 * Define the Position Profile Metrics measurement.
	 * @see #Metrics
	 * The value of this field is "<i>prefix/<i><b>PositionProfile/Metrics</b>"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String METRICS_EXTERNAL_KEY = "PositionProfile/Metrics"; //$NON-NLS-1$

	/**
	 * Define the Position Profile Metrics measurement.
	 * @see #Metrics
	 * The value of this field is "<i>prefix/<i><b>PositionProfile/Metrics</b>/get"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String METRICS_GET_EXTERNAL_KEY = GpsNmeaPositionProfileService.METRICS_EXTERNAL_KEY + NotificationService.GET_EXTERNAL_KEY;

	/**
	 * Define the Position Profile Metrics measurement.
	 * @see #Metrics
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>PositionProfile/Metrics</b>/error"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String METRICS_ERROR_EXTERNAL_KEY = GpsNmeaPositionProfileService.METRICS_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;
}
