package org.eclipse.soda.dk.gps.nmea.position.profile.test.factory;

/*************************************************************************
 * Copyright (c) 2008, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.util.Dictionary;
import java.util.Hashtable;

import org.eclipse.soda.dk.gps.nmea.position.profile.service.GpsNmeaPositionProfileService;
import org.eclipse.soda.dk.gps.nmea.position.profile.test.GpsNmeaPositionProfileTest;
import org.eclipse.soda.dk.gps.nmea.position.profile.test.service.GpsNmeaPositionProfileTestService;
import org.eclipse.soda.dk.notification.service.NotificationService;
import org.eclipse.soda.dk.profile.service.ProfileService;
import org.eclipse.soda.dk.profile.test.factory.ProfileTestFactory;
import org.eclipse.soda.dk.profile.test.service.ProfileTestService;
import org.eclipse.soda.sat.core.framework.interfaces.IBundleActivationManager;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.Constants;

/**
 * Gps Nmea Profile.
 * <p>The device bundle activator class creates and registers the GpsNmeaPositionProfileTest device.
 * <p>The list of exported services:
 * @see org.eclipse.soda.dk.gps.nmea.position.profile.test.service.GpsNmeaPositionProfileTestService
 * @see org.eclipse.soda.dk.profile.service.ProfileService
 *  
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class GpsNmeaPositionProfileTestFactory extends ProfileTestFactory implements BundleActivator {
	/**
	 * Defines the full class name.
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String CLASS_NAME = "org.eclipse.soda.dk.gps.nmea.position.profile.test.factory.GpsNmeaPositionProfileTestFactory"; //$NON-NLS-1$

	/**
	 * Defines the service name(s) to be registered by the GpsNmeaPositionProfile bundle.
	 * <table>
	 * <tr>
	 * <td>org.
	 * eclipse.
	 * soda.
	 * dk.
	 * gps.
	 * nmea.
	 * position.
	 * profile.
	 * test.
	 * service.
	 * GpsNmeaPositionProfileTestService</td>.
	 * </tr>
	 * </table>
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String[] EXPORTED_SERVICE_NAMES = new String[] { GpsNmeaPositionProfileTestService.SERVICE_NAME };

	/**
	 * Defines the imported service name(s) to be registered by the GpsNmeaPositionProfileTest bundle.
	 * <table>
	 * <tr>
	 * <td>org.eclipse.soda.dk.gps.nmea.position.profile.service.GpsNmeaPositionProfileService</td>
	 * </tr>
	 * <tr>
	 * <td>org.eclipse.soda.dk.notification.service.NotificationService</td>
	 * </tr>
	 * </table>
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String[] IMPORTED_SERVICE_NAMES = new String[] { GpsNmeaPositionProfileService.SERVICE_NAME, NotificationService.SERVICE_NAME };

	/**
	 * Gets the properties to be registered with the service(s).
	 * @return Hashtable of properties.
	 * 
	 * <table width=100%>
	 * <tr>
	 * <td width=50%>org.osgi.framework.Constants.SERVICE_PID</td>
	 * <td width=50%>GpsNmeaPositionProfileTestService.SERVICE_NAME</td>
	 * </tr>
	 * <tr>
	 * <td width=50%>org.osgi.framework.Constants.SERVICE_DESCRIPTION</td>
	 * <td width=50%>GpsNmeaPositionProfileTestService.SERVICE_DESCRIPTION</td>
	 * </tr>
	 * <tr>
	 * <td width=50%>org.osgi.framework.Constants.SERVICE_RANKING</td>
	 * <td width=50%>6</td>
	 * </tr>
	 * <tr>
	 * <td width=50%>org.osgi.framework.Constants.SERVICE_VENDOR</td>
	 * <td width=50%>IBM</td>
	 * </tr>
	 * </table>
	 * @since 1.1
	 */
	public Hashtable createProperties() {
		/* Generated method and should not be changed. */
		final Hashtable properties = super.createProperties();
		properties.put(Constants.SERVICE_PID, GpsNmeaPositionProfileTestService.SERVICE_NAME);
		properties.put(Constants.SERVICE_DESCRIPTION, GpsNmeaPositionProfileTestService.SERVICE_DESCRIPTION);
		properties.put(Constants.SERVICE_RANKING, "6"); //$NON-NLS-1$
		properties.put(Constants.SERVICE_VENDOR, "IBM"); //$NON-NLS-1$
		return properties;
	}

	/**
	 * Creates the test for the specified profile.
	 * 
	 * @param profile ProfileService
	 * @return org.eclipse.soda.dk.profile.test.service.ProfileTestService The profile test.
	 * @see org.eclipse.soda.dk.gps.nmea.position.profile.test.GpsNmeaPositionProfileTest
	 * @since 1.1
	 */
	public ProfileTestService createService(final ProfileService profile) {
		/* Generated method and should not be changed. */
		final GpsNmeaPositionProfileTest test = new GpsNmeaPositionProfileTest();
		test.setProfile(profile);
		return test;
	}

	/**
	 * Return the exported service name(s) to be registered by the GpsNmeaPositionProfile bundle.
	 * @return String[] The exported service name(s).
	 * @param pid PID.
	 * @param oldProperties old properties.
	 * @param properties properties.
	 * @param manager manager.
	 * @since 1.1
	 */
	public String[] getExportedServiceNames(final String pid, final Dictionary oldProperties, final Dictionary properties, final IBundleActivationManager manager) {
		/* Generated method and should not be changed. */
		return EXPORTED_SERVICE_NAMES;
	}

	/**
	 * Return the imported service name(s) to be registered by the GpsNmeaPositionProfileTest bundle.
	 * @return String[] The imported service names.
	 * @param pid PID.
	 * @param oldProperties old properties.
	 * @param properties properties.
	 * @param manager manager.
	 * @since 1.1
	 */
	public String[] getImportedServiceNames(final String pid, final Dictionary oldProperties, final Dictionary properties, final IBundleActivationManager manager) {
		/* Generated method and should not be changed. */
		return IMPORTED_SERVICE_NAMES;
	}

	/**
	 * Gets the profile service name to be tested.
	 * 
	 * @return String The interest service name.
	 * @see org.eclipse.soda.dk.gps.nmea.position.profile.service.GpsNmeaPositionProfileService
	 * @since 1.1
	 */
	public String getInterestServiceName() {
		/* Generated method and should not be changed. */
		return org.eclipse.soda.dk.gps.nmea.position.profile.service.GpsNmeaPositionProfileService.SERVICE_NAME;
	}
}
