package org.eclipse.soda.dk.gps.nmea.transport.bundle;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.util.Hashtable;

import org.eclipse.soda.dk.connection.bundle.ServiceBundle;
import org.eclipse.soda.dk.connection.service.ConnectionService;
import org.eclipse.soda.dk.gps.nmea.transport.GpsNmeaTransport;
import org.eclipse.soda.dk.gps.nmea.transport.service.GpsNmeaTransportService;
import org.eclipse.soda.dk.transport.ConnectionTransport;
import org.eclipse.soda.dk.transport.bundle.TransportBundle;
import org.eclipse.soda.dk.transport.service.TransportService;
import org.osgi.framework.BundleActivator;
import org.osgi.service.device.Constants;

/**
 * Global Positioning System (GPS) National Marine Electronics Association (NMEA) Transport.
 * 
 *  <p>The transport bundle activator class creates and registers the GpsNmeaTransport transport.
 * <p>The Device Kit properties CONNECTION_KEYS and default values.
 * <table>
 *  
 * 	<tr>
 * 		<td>gpsnmeatransport.databits</td>
 * 		<td>8</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.comport</td>
 * 		<td>1</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.readtotaltimeout</td>
 * 		<td>1000</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.readintervaltimeout</td>
 * 		<td>50</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.hardwareflowcontrol</td>
 * 		<td>0</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.softwareflowcontrol</td>
 * 		<td>0</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.stopbits</td>
 * 		<td>1</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.writetotaltimeout</td>
 * 		<td>100</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.parity</td>
 * 		<td>none</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.baudrate</td>
 * 		<td>4800</td>
 * 	</tr>
 *  
 * 	<tr>
 * 		<td>gpsnmeatransport.writesize</td>
 * 		<td>-1</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.linger</td>
 * 		<td>-1</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.readsize</td>
 * 		<td>-1</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.remoteport</td>
 * 		<td>8901</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.host</td>
 * 		<td>localhost</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.readtimeout</td>
 * 		<td>1000</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.localport</td>
 * 		<td>-1</td>
 * 	</tr>
 *  
 * 	<tr>
 * 		<td>gpsnmeatransport.connection</td>
 * 		<td>serial</td>
 * 	</tr>
 * </table>
 *  
 * <xmp>
 * 	gpsnmeatransport.databits=8
 * 	gpsnmeatransport.comport=1
 * 	gpsnmeatransport.readtotaltimeout=1000
 * 	gpsnmeatransport.readintervaltimeout=50
 * 	gpsnmeatransport.hardwareflowcontrol=0
 * 	gpsnmeatransport.softwareflowcontrol=0
 * 	gpsnmeatransport.stopbits=1
 * 	gpsnmeatransport.writetotaltimeout=100
 * 	gpsnmeatransport.parity=none
 * 	gpsnmeatransport.baudrate=4800
 * </xmp>
 *  
 *  
 * <xmp>
 * 	gpsnmeatransport.writesize=-1
 * 	gpsnmeatransport.linger=-1
 * 	gpsnmeatransport.readsize=-1
 * 	gpsnmeatransport.remoteport=8901
 * 	gpsnmeatransport.host=localhost
 * 	gpsnmeatransport.readtimeout=1000
 * 	gpsnmeatransport.localport=-1
 * </xmp>
 *  
 *  
 * <xmp>
 * 	gpsnmeatransport.connection=serial
 * </xmp>
 *  
 * <p>The list of exported services:
 * @see org.eclipse.soda.dk.gps.nmea.transport.service.GpsNmeaTransportService
 * @see org.eclipse.soda.dk.transport.service.TransportService
 *  
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class GpsNmeaTransportBundle extends TransportBundle implements BundleActivator {
	/**
	 * Defines the full class name.
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String CLASS_NAME = "org.eclipse.soda.dk.gps.nmea.transport.bundle.GpsNmeaTransportBundle"; //$NON-NLS-1$

	/**
	 * Defines the org.osgi.service.device.Constants.DEVICE_CATEGORY property.
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String[] DEVICE_CATEGORY = new String[] { "TransportService" }; //$NON-NLS-1$

	/**
	 * Defines the service name(s) to be registered by the GpsNmeaTransport bundle.
	 * <table>
	 * <tr>
	 * <td>org.eclipse.soda.dk.transport.service.TransportService</td>
	 * </tr>
	 * </table>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String[] EXPORTED_SERVICE_NAMES = new String[] { GpsNmeaTransportService.SERVICE_NAME, TransportService.SERVICE_NAME };

	/**
	 * Gets the properties to be registered with the service(s).
	 * @return Hashtable of properties.
	 * 
	 * <table width=100%>
	 * <tr>
	 * <td width=50%>org.osgi.service.device.Constants.DRIVER_ID</td>
	 * <td width=50%>GpsNmeaTransport</td>
	 * </tr>
	 * <tr>
	 * <td width=50%>org.osgi.framework.Constants.SERVICE_PID</td>
	 * <td width=50%>GpsNmeaTransportService.SERVICE_NAME</td>
	 * </tr>
	 * <tr>
	 * <td width=50%>org.eclipse.soda.dk.connection.bundle.ServiceBundle.DEVICE_CLASS</td>
	 * <td width=50%>GpsNmea</td>
	 * </tr>
	 * <tr>
	 * <td width=50%>org.osgi.service.device.Constants.DEVICE_CATEGORY</td>
	 * <td width=50%>TransportService</td>
	 * </tr>
	 * <tr>
	 * <td width=50%>org.osgi.framework.Constants.SERVICE_RANKING</td>
	 * <td width=50%>6</td>
	 * </tr>
	 * </table>
	 * @since 1.0
	 */
	public Hashtable createProperties() {
		/* Generated method and should not be changed. */
		final Hashtable properties = super.createProperties();
		properties.put(Constants.DRIVER_ID, "GpsNmeaTransport"); //$NON-NLS-1$
		properties.put(org.osgi.framework.Constants.SERVICE_PID, GpsNmeaTransportService.SERVICE_NAME);
		properties.put(ServiceBundle.DEVICE_CLASS, "GpsNmea"); //$NON-NLS-1$
		properties.put(Constants.DEVICE_CATEGORY, DEVICE_CATEGORY);
		properties.put(org.osgi.framework.Constants.SERVICE_RANKING, "6"); //$NON-NLS-1$
		return properties;
	}

	/**
	 * Creates the transport service to be registered with the OSGi system.
	 * 
	 * @param connection The connection service to be used when creating this transport service.
	 * @return Object The transport service
	 * @see org.eclipse.soda.dk.gps.nmea.transport.GpsNmeaTransport
	 * @since 1.0
	 */
	public TransportService createService(final ConnectionService connection) {
		/* Generated method and should not be changed. */
		final ConnectionTransport transport = new GpsNmeaTransport();
		transport.setConnection(connection);
		return transport;
	}

	/**
	 * Return the exported service name(s) to be registered by the GpsNmeaTransport bundle.
	 * @return String[] The transport's service names.
	 * @since 1.0
	 */
	public String[] getExportedServiceNames() {
		/* Generated method and should not be changed. */
		return EXPORTED_SERVICE_NAMES;
	}
}
