package org.eclipse.soda.dk.gps.nmea.transport.service;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import org.eclipse.soda.dk.serial.connection.service.SerialConnectionService;
import org.eclipse.soda.dk.transport.service.TransportService;

/**
 * Global Positioning System (GPS) National Marine Electronics Association (NMEA) Transport.
 * 
 *  The transport service interface defines the service to be registered for the GpsNmeaTransport transport. 
 *  
 * <p>The list of exported services:
 * @see org.eclipse.soda.dk.gps.nmea.transport.service.GpsNmeaTransportService
 * @see org.eclipse.soda.dk.transport.service.TransportService
 *  
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public interface GpsNmeaTransportService extends TransportService {
	/**
	 * Define the OSGi service name.
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String SERVICE_NAME = "org.eclipse.soda.dk.gps.nmea.transport.service.GpsNmeaTransportService"; //$NON-NLS-1$

	/**
	 * Define the OSGi managed service name.
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String MANAGED_SERVICE_NAME = "org.eclipse.soda.dk.gps.nmea.transport.managed.GpsNmeaTransportManaged"; //$NON-NLS-1$

	/**
	 * Define the OSGi factory service name.
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String FACTORY_SERVICE_NAME = "org.eclipse.soda.dk.gps.nmea.transport.factory.GpsNmeaTransportFactory"; //$NON-NLS-1$

	/**
	 * The communication port number.
	 * @see #SERIAL_COMPORT_PROPERTY
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final int SERIAL_COMPORT_DEFAULT = 1;

	/**
	 * The communication port number.
	 * The key in the esc.property file must match this field.
	 * @see #SERIAL_COMPORT_DEFAULT
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final String SERIAL_COMPORT_PROPERTY = "gpsnmeatransport.comport"; //$NON-NLS-1$

	/**
	 * The baud rate.
	 * @see #SERIAL_BAUDRATE_PROPERTY
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final int SERIAL_BAUDRATE_DEFAULT = 4800;

	/**
	 * The baud rate.
	 * The key in the esc.property file must match this field.
	 * @see #SERIAL_BAUDRATE_DEFAULT
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final String SERIAL_BAUDRATE_PROPERTY = "gpsnmeatransport.baudrate"; //$NON-NLS-1$

	/**
	 * The data bits.
	 * @see #SERIAL_DATABITS_PROPERTY
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final int SERIAL_DATABITS_DEFAULT = 8;

	/**
	 * The data bits.
	 * The key in the esc.property file must match this field.
	 * @see #SERIAL_DATABITS_DEFAULT
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final String SERIAL_DATABITS_PROPERTY = "gpsnmeatransport.databits"; //$NON-NLS-1$

	/**
	 * The parity.
	 * @see #SERIAL_PARITY_PROPERTY
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final int SERIAL_PARITY_DEFAULT = SerialConnectionService.Parity.None;

	/**
	 * The parity.
	 * The key in the esc.property file must match this field.
	 * @see #SERIAL_PARITY_DEFAULT
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final String SERIAL_PARITY_PROPERTY = "gpsnmeatransport.parity"; //$NON-NLS-1$

	/**
	 * The stop bits.
	 * @see #SERIAL_STOPBITS_PROPERTY
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final int SERIAL_STOPBITS_DEFAULT = SerialConnectionService.Stopbits.A1_5;

	/**
	 * The stop bits.
	 * The key in the esc.property file must match this field.
	 * @see #SERIAL_STOPBITS_DEFAULT
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final String SERIAL_STOPBITS_PROPERTY = "gpsnmeatransport.stopbits"; //$NON-NLS-1$

	/**
	 * The hardware flow control.
	 * @see #SERIAL_HARDWAREFLOWCONTROL_PROPERTY
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final int SERIAL_HARDWAREFLOWCONTROL_DEFAULT = SerialConnectionService.Hardwareflowcontrol.Zero;

	/**
	 * The hardware flow control.
	 * The key in the esc.property file must match this field.
	 * @see #SERIAL_HARDWAREFLOWCONTROL_DEFAULT
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final String SERIAL_HARDWAREFLOWCONTROL_PROPERTY = "gpsnmeatransport.hardwareflowcontrol"; //$NON-NLS-1$

	/**
	 * The software flow control.
	 * @see #SERIAL_SOFTWAREFLOWCONTROL_PROPERTY
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final int SERIAL_SOFTWAREFLOWCONTROL_DEFAULT = SerialConnectionService.Softwareflowcontrol.Zero;

	/**
	 * The software flow control.
	 * The key in the esc.property file must match this field.
	 * @see #SERIAL_SOFTWAREFLOWCONTROL_DEFAULT
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final String SERIAL_SOFTWAREFLOWCONTROL_PROPERTY = "gpsnmeatransport.softwareflowcontrol"; //$NON-NLS-1$

	/**
	 * The read total timeout in milliseconds.
	 * @see #SERIAL_READTOTALTIMEOUT_PROPERTY
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final long SERIAL_READTOTALTIMEOUT_DEFAULT = 1000;

	/**
	 * The read total timeout in milliseconds.
	 * The key in the esc.property file must match this field.
	 * @see #SERIAL_READTOTALTIMEOUT_DEFAULT
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final String SERIAL_READTOTALTIMEOUT_PROPERTY = "gpsnmeatransport.readtotaltimeout"; //$NON-NLS-1$

	/**
	 * The read interval timeout in milliseconds.
	 * @see #SERIAL_READINTERVALTIMEOUT_PROPERTY
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final long SERIAL_READINTERVALTIMEOUT_DEFAULT = 50;

	/**
	 * The read interval timeout in milliseconds.
	 * The key in the esc.property file must match this field.
	 * @see #SERIAL_READINTERVALTIMEOUT_DEFAULT
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final String SERIAL_READINTERVALTIMEOUT_PROPERTY = "gpsnmeatransport.readintervaltimeout"; //$NON-NLS-1$

	/**
	 * The write total timeout in milliseconds.
	 * @see #SERIAL_WRITETOTALTIMEOUT_PROPERTY
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final long SERIAL_WRITETOTALTIMEOUT_DEFAULT = 100;

	/**
	 * The write total timeout in milliseconds.
	 * The key in the esc.property file must match this field.
	 * @see #SERIAL_WRITETOTALTIMEOUT_DEFAULT
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final String SERIAL_WRITETOTALTIMEOUT_PROPERTY = "gpsnmeatransport.writetotaltimeout"; //$NON-NLS-1$

	/**
	 * The local host name or address.
	 * @see #TCPIP_LOCALHOST_PROPERTY
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final String TCPIP_LOCALHOST_DEFAULT = "0.0.0.0"; //$NON-NLS-1$

	/**
	 * The local host name or address.
	 * The key in the esc.property file must match this field.
	 * @see #TCPIP_LOCALHOST_DEFAULT
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final String TCPIP_LOCALHOST_PROPERTY = "gpsnmeatransport.localhost"; //$NON-NLS-1$

	/**
	 * The local port number.
	 * @see #TCPIP_LOCALPORT_PROPERTY
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final int TCPIP_LOCALPORT_DEFAULT = -1;

	/**
	 * The local port number.
	 * The key in the esc.property file must match this field.
	 * @see #TCPIP_LOCALPORT_DEFAULT
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final String TCPIP_LOCALPORT_PROPERTY = "gpsnmeatransport.localport"; //$NON-NLS-1$

	/**
	 * The remote host name or address.
	 * @see #TCPIP_REMOTEHOST_PROPERTY
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final String TCPIP_REMOTEHOST_DEFAULT = "localhost"; //$NON-NLS-1$

	/**
	 * The remote host name or address.
	 * The key in the esc.property file must match this field.
	 * @see #TCPIP_REMOTEHOST_DEFAULT
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final String TCPIP_REMOTEHOST_PROPERTY = "gpsnmeatransport.remotehost"; //$NON-NLS-1$

	/**
	 * The remote port number on the host.
	 * @see #TCPIP_REMOTEPORT_PROPERTY
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final int TCPIP_REMOTEPORT_DEFAULT = 8901;

	/**
	 * The remote port number on the host.
	 * The key in the esc.property file must match this field.
	 * @see #TCPIP_REMOTEPORT_DEFAULT
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final String TCPIP_REMOTEPORT_PROPERTY = "gpsnmeatransport.remoteport"; //$NON-NLS-1$

	/**
	 * The read timeout value in milliseconds.
	 * @see #TCPIP_READTIMEOUT_PROPERTY
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final int TCPIP_READTIMEOUT_DEFAULT = 1000;

	/**
	 * The read timeout value in milliseconds.
	 * The key in the esc.property file must match this field.
	 * @see #TCPIP_READTIMEOUT_DEFAULT
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final String TCPIP_READTIMEOUT_PROPERTY = "gpsnmeatransport.readtimeout"; //$NON-NLS-1$

	/**
	 * The read size value in bytes.
	 * @see #TCPIP_READSIZE_PROPERTY
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final int TCPIP_READSIZE_DEFAULT = -1;

	/**
	 * The read size value in bytes.
	 * The key in the esc.property file must match this field.
	 * @see #TCPIP_READSIZE_DEFAULT
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final String TCPIP_READSIZE_PROPERTY = "gpsnmeatransport.readsize"; //$NON-NLS-1$

	/**
	 * The write size value in bytes.
	 * @see #TCPIP_WRITESIZE_PROPERTY
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final int TCPIP_WRITESIZE_DEFAULT = -1;

	/**
	 * The write size value in bytes.
	 * The key in the esc.property file must match this field.
	 * @see #TCPIP_WRITESIZE_DEFAULT
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final String TCPIP_WRITESIZE_PROPERTY = "gpsnmeatransport.writesize"; //$NON-NLS-1$

	/**
	 * The linger value.
	 * @see #TCPIP_LINGER_PROPERTY
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final int TCPIP_LINGER_DEFAULT = -1;

	/**
	 * The linger value.
	 * The key in the esc.property file must match this field.
	 * @see #TCPIP_LINGER_DEFAULT
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final String TCPIP_LINGER_PROPERTY = "gpsnmeatransport.linger"; //$NON-NLS-1$

	/**
	 * The remote host name or address.
	 * use remotehost
	 * @see #TCPIP_HOST_PROPERTY
	 * @since 1.2
	 */
	// Generated field and should not be changed.
	public static final String TCPIP_HOST_DEFAULT = "localhost"; //$NON-NLS-1$
}
