package org.eclipse.soda.dk.gps.nmea.transport.test.bundle;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.util.Hashtable;

import org.eclipse.soda.dk.gps.nmea.transport.service.GpsNmeaTransportService;
import org.eclipse.soda.dk.gps.nmea.transport.test.GpsNmeaTransportTest;
import org.eclipse.soda.dk.gps.nmea.transport.test.service.GpsNmeaTransportTestService;
import org.eclipse.soda.dk.notification.service.NotificationService;
import org.eclipse.soda.dk.transport.service.TransportService;
import org.eclipse.soda.dk.transport.test.bundle.TransportTestBundle;
import org.eclipse.soda.dk.transport.test.service.TransportTestService;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.Constants;

/**
 * Global Positioning System (GPS) National Marine Electronics Association (NMEA) Transport.
 * <p>The device bundle activator class creates and registers the GpsNmeaTransportTest device.
 * <p>The list of exported services:
 * @see org.eclipse.soda.dk.gps.nmea.transport.test.service.GpsNmeaTransportTestService
 * @see org.eclipse.soda.dk.transport.service.TransportService
 *  
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class GpsNmeaTransportTestBundle extends TransportTestBundle implements BundleActivator {
	/**
	 * Defines the full class name.
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String CLASS_NAME = "org.eclipse.soda.dk.gps.nmea.transport.test.bundle.GpsNmeaTransportTestBundle"; //$NON-NLS-1$

	/**
	 * Defines the service name(s) to be registered by the GpsNmeaTransport bundle.
	 * <table>
	 * <tr>
	 * <td>org.eclipse.soda.dk.gps.nmea.transport.test.service.GpsNmeaTransportTestService</td>
	 * </tr>
	 * </table>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String[] EXPORTED_SERVICE_NAMES = new String[] { GpsNmeaTransportTestService.SERVICE_NAME };

	/**
	 * Defines the imported service name(s) to be registered by the GpsNmeaTransportTest bundle.
	 * <table>
	 * <tr>
	 * <td>org.eclipse.soda.dk.gps.nmea.transport.service.GpsNmeaTransportService</td>
	 * </tr>
	 * <tr>
	 * <td>org.eclipse.soda.dk.notification.service.NotificationService</td>
	 * </tr>
	 * </table>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String[] IMPORTED_SERVICE_NAMES = new String[] { GpsNmeaTransportService.SERVICE_NAME, NotificationService.SERVICE_NAME };

	/**
	 * Gets the properties to be registered with the service(s).
	 * @return Hashtable of properties.
	 * 
	 * <table width=100%>
	 * <tr>
	 * <td width=50%>org.osgi.framework.Constants.SERVICE_PID</td>
	 * <td width=50%>GpsNmeaTransportTestService.SERVICE_NAME</td>
	 * </tr>
	 * <tr>
	 * <td width=50%>org.osgi.framework.Constants.SERVICE_DESCRIPTION</td>
	 * <td width=50%>GpsNmeaTransportTestService.SERVICE_DESCRIPTION</td>
	 * </tr>
	 * <tr>
	 * <td width=50%>org.osgi.framework.Constants.SERVICE_RANKING</td>
	 * <td width=50%>6</td>
	 * </tr>
	 * <tr>
	 * <td width=50%>org.osgi.framework.Constants.SERVICE_VENDOR</td>
	 * <td width=50%>IBM</td>
	 * </tr>
	 * </table>
	 * @since 1.0
	 */
	public Hashtable createProperties() {
		/* Generated method and should not be changed. */
		final Hashtable properties = super.createProperties();
		properties.put(Constants.SERVICE_PID, GpsNmeaTransportTestService.SERVICE_NAME);
		properties.put(Constants.SERVICE_DESCRIPTION, GpsNmeaTransportTestService.SERVICE_DESCRIPTION);
		properties.put(Constants.SERVICE_RANKING, "6"); //$NON-NLS-1$
		properties.put(Constants.SERVICE_VENDOR, "IBM"); //$NON-NLS-1$
		return properties;
	}

	/**
	 * Creates the test for the specified transport.
	 * 
	 * @param transport TransportService
	 * @return org.eclipse.soda.dk.transport.test.service.TransportTestService The transport test.
	 * @see org.eclipse.soda.dk.gps.nmea.transport.test.GpsNmeaTransportTest
	 * @since 1.0
	 */
	public TransportTestService createService(final TransportService transport) {
		/* Generated method and should not be changed. */
		final GpsNmeaTransportTest test = new GpsNmeaTransportTest();
		test.setTransport(transport);
		return test;
	}

	/**
	 * Return the exported service name(s) to be registered by the GpsNmeaTransport bundle.
	 * @return String[] The exported service name(s).
	 * @since 1.0
	 */
	public String[] getExportedServiceNames() {
		/* Generated method and should not be changed. */
		return EXPORTED_SERVICE_NAMES;
	}

	/**
	 * Return the imported service name(s) to be registered by the GpsNmeaTransportTest bundle.
	 * @return String[] The imported service names.
	 * @since 1.0
	 */
	public String[] getImportedServiceNames() {
		/* Generated method and should not be changed. */
		return IMPORTED_SERVICE_NAMES;
	}

	/**
	 * Gets the transport service name to be tested.
	 * 
	 * @return String The interest service name.
	 * @see org.eclipse.soda.dk.gps.nmea.transport.service.GpsNmeaTransportService
	 * @since 1.0
	 */
	public String getInterestServiceName() {
		/* Generated method and should not be changed. */
		return org.eclipse.soda.dk.gps.nmea.transport.service.GpsNmeaTransportService.SERVICE_NAME;
	}
}
